@@ -18,7 +18,8 @@ IMG_CLASSES = ['f-m-img', 'group-pic', 'image-wrapper',
 	'photo_wrap', 'hideBeforeLoad', 'slide_container', 'rich_media_content',
 	'is-widgets', 'entry-content', 'image-show', 
 	'o-noteContentImage__item', 'open-list-post-description',
-	'open-list-media-container', 'article-inline-photo']
+	'open-list-media-container', 'article-inline-photo',
+	'tl_article_content']
 
 try:
 	with open('CREDENTIALS') as f:
@@ -95,10 +96,13 @@ def getSrc(img, path):
 		return src
 	return
 
-def enlarge(src):
+def enlarge(src, img):
 	if not src:
 		return None
-	return src.replace('/m/', '/l/')
+	src = src.replace('/m/', '/l/')
+	if 'animate' in img.parent.get('class'):
+		src = '.'.join(src.split('.')[:-1]) + '.mp4'
+	return src
 
 def withDomain(path, x):
 	if x.startswith('//'):
@@ -110,7 +114,7 @@ def withDomain(path, x):
 	return x
 
 def getImgs(b, path):
-	raw = [enlarge(getSrc(img, path)) for img in b.find_all('img')]
+	raw = [enlarge(getSrc(img, path), img) for img in b.find_all('img')]
 	return [withDomain(path, x) for x in raw if x]
 
 def getVideo(b):
